## Installation (Python)

Install μAgents for Python 3.8 to 3.12:

```bash
poetry install
poetry shell
```

## Documentation

Build and run the docs locally with:

```bash
mkdocs serve
```

Or go to the official docs site: https://docs.fetch.ai/uAgents.

## Examples

The [`examples`](https://github.com/fetchai/uAgents/tree/main/python/examples) folder contains several examples of how to create and run various types of agents.